.. contents::

==================
django-inplaceedit
==================

Information
===========

.. image:: https://travis-ci.org/django-inplaceedit/django-inplaceedit.png?branch=master
    :target: https://travis-ci.org/django-inplaceedit/django-inplaceedit

.. image:: https://coveralls.io/repos/django-inplaceedit/django-inplaceedit/badge.png?branch=master
    :target: https://coveralls.io/r/django-inplaceedit/django-inplaceedit

.. image:: https://badge.fury.io/py/django-inplaceedit.png
    :target: https://badge.fury.io/py/django-inplaceedit

.. image:: https://readthedocs.org/projects/django-inplaceedit/badge/?version=latest
    :target: https://readthedocs.org/projects/django-inplaceedit/?badge=latest
    :alt: Documentation Status


Inplace Edit Form is a Django application that allows you to inline edition of some data from the database

It is distributed under the terms of the GNU Lesser General Public
License <http://www.gnu.org/licenses/lgpl.html>

Demo (this video use a very old version of django-inplaceedit and django-inplaceedit-extra-fields)
==================================================================================================

Video Demo, of django-inplaceedit, `django-inplaceedit-extra-fields <http://pypi.python.org/pypi/django-inplaceedit-extra-fields>`_ and `django-inlinetrans <http://pypi.python.org/pypi/django-inlinetrans>`_ (Set full screen mode to view it correctly)

.. image:: https://github.com/django-inplaceedit/django-inplaceedit/raw/master/video-frame.png
   :target: http://youtu.be/_EjisXtMy_Y?t=34s


Requirements
============

 * `Django <https://www.djangoproject.com/>`_ (>= 1.2, even works with 1.1 with some customizations in your project)
 * `jQuery <http://jquery.com/>`_ (>=1.6)


Other packages related
======================

 * `django-transmeta <http://pypi.python.org/pypi/django-transmeta>`_, django-inplaceedit supports django-transmeta. django-transmeta is an application for translatable content in Django's models
 * `django-inplace-edit-extra-field <http://pypi.python.org/pypi/django-inplaceedit-extra-fields>`_, with this egg you can extends the default adaptors of django-inplaceedit
 * `django-inplace-edit-bootstrap <http://pypi.python.org/pypi/django-inplaceedit-bootstrap>`_, integration of django-inplaceedit with Bootstrap 3.

Documentation
=============

You can find more in the documentation at https://django-inplaceedit.readthedocs.org/en/latest/

Development
===========

You can get the bleeding edge version of django-inplaceedit by doing a clone
of its git repository::

  git clone git://github.com/django-inplaceedit/django-inplaceedit.git
